@@ -26,21 +26,12 @@ from django.conf import settings
 from django.urls import reverse
 from django.http import JsonResponse, Http404
 from django.views.decorators.csrf import csrf_exempt
+from django.dispatch import Signal
 
 from Iuno.cloud.sms import SMS, verify
 from Iuppiter.Encryption import Encryptor
 
-def importClass(cls):
-    fullClass = cls.rsplit(".", 1)
-    module = importlib.import_module(fullClass[0])
-    cls = getattr(module, fullClass[1])
-    return cls
-
-if getattr(settings, "IUNO_CLOUD_SMS_AFTER_VIRIFY_METHOD", None):
-    IUNO_CLOUD_SMS_AFTER_VIRIFY_METHOD = importClass(
-        getattr(settings, "IUNO_CLOUD_SMS_AFTER_VIRIFY_METHOD", None))
-else:
-    IUNO_CLOUD_SMS_AFTER_VIRIFY_METHOD = None
+smsAfterVerify = Signal()
 
 @csrf_exempt  
 def sendSMSAuthentication(request):
@@ -60,9 +51,8 @@ def sendSMSAuthentication(request):
         result = verify(phone, template=temp, **count)
         
         # after
-        if IUNO_CLOUD_SMS_AFTER_VIRIFY_METHOD:
-            IUNO_CLOUD_SMS_AFTER_VIRIFY_METHOD(request)
-       
+        smsAfterVerify.send(sender=sendSMSAuthentication, request=request)
+        
         response = JsonResponse(result)
         response["Access-Control-Allow-Origin"] = "*"
         return response
